@@ -6,7 +6,7 @@
  */
 
 /*
-    Copyright 2011-2015 Thibaut Paumard, Frederic Vincent
+    Copyright 2011-2016 Thibaut Paumard, Frederic Vincent
 
     This file is part of Gyoto.
 
@@ -118,7 +118,7 @@ namespace Gyoto{
      * an XML file, as in &lt;Astrobj kind="name"&gt;
      *
      * \param scp A pointer to the subcontractor, which will
-     * communicate whith the Gyoto::Factory to build an instance of
+     * communicate with the Gyoto::Factory to build an instance of
      * the class from its XML description
      */
     void Register(std::string name, Gyoto::Astrobj::Subcontractor_t* scp);
@@ -216,6 +216,7 @@ class Gyoto::Astrobj::Generic
   bool flag_radtransf_; ///< 1 if radiative transfer inside Astrobj, else 0
 
   int radiativeq_; ///< 1 to use the new radiativeQ function (under dvp)
+  int shadow_; ///< 1 to highlight the shadow region in the image
   int noredshift_; ///< 1 to impose redshift factor g = 1
   // Constructors - Destructor
   // -------------------------
@@ -340,6 +341,9 @@ class Gyoto::Astrobj::Generic
   void radiativeQ(bool flag);
   bool radiativeQ() const ;
 
+  void showshadow(bool flag);
+  bool showshadow() const ;
+
   void redshift(bool flag);
   bool redshift() const ;
 
